## -------------------------------------------------------------------------- #
#           ____  _____________  __                                           #
#          / __ \/ ____/ ___/\ \/ /                 _   _   _                 #
#         / / / / __/  \__ \  \  /                 / \ / \ / \                #
#        / /_/ / /___ ___/ /  / /               = ( M | S | K )=              #
#       /_____/_____//____/  /_/                   \_/ \_/ \_/                #
#                                                                             #
# --------------------------------------------------------------------------- #
# @copyright Copyright 2019-2023 DESY
# SPDX-License-Identifier: Apache-2.0
# --------------------------------------------------------------------------- #
# @date 2023-1-26
# @author Seyed Nima Omidsajedi  <nima.sajedi@desy.de>
# @author Lukasz Butkowski <lukasz.butkowski@desy.de>
# --------------------------------------------------------------------------- #
# @brief
# Part of DESY FPGA Firmware Framework (fwk)
# Supplementary Tcl script for laoding Vitis HLS tool in the firmware framework.
# --------------------------------------------------------------------------- #
#!/usr/bin/env tclsh

source ./fwk/src/main.tcl

# main function
set commonArgs "-c $::env(cfgFile) -t vitis_hls --colorterm $::env(COLORTERM) --exit"

switch $env(hls_target) {
  "vitis_hls"   {
    ::fwk::catchHdl "::fwk::main init create $commonArgs"
  }
  "vitis_hls_sim" {
    ::fwk::catchHdl "::fwk::main init simulate $commonArgs"
  }
  "vitis_hls_build" {
    ::fwk::catchHdl "::fwk::main init create build $commonArgs"
  }
  "vitis_hls_synth" {
    ::fwk::catchHdl "::fwk::main init create synth $commonArgs"
  }
  "vitis_hls_gui" {
    ::fwk::catchHdl "::fwk::main init gui $commonArgs"
  }
  default  {
    puts "Unrecognized command"
    return -1
  }
}
